@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12609 2020-11-12 18:17:22Z Lavender $
+# $Id: setup.py 12629 2020-11-26 13:42:29Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-11-13 03:17:22 +0900 (週五, 13 十一月 2020) $
-# $Revision: 12609 $
+# $Date: 2020-11-26 22:42:29 +0900 (週四, 26 十一月 2020) $
+# $Revision: 12629 $
 
 import re
 import os
@@ -486,7 +486,7 @@ if __name__ == "__main__":
         parser = argparse.ArgumentParser(description='Path to Project')
         parser.add_argument(
             "path", metavar='path', 
-            type=str,  nargs='?', default=".",
+            type=str, 
             help="Path to project, default is '.'"
         )
         
@@ -506,7 +506,7 @@ if __name__ == "__main__":
             '-w', '--wizard', 
             action='store_true',
             help="Run the configuration wizard")   
-       
+
         args = parser.parse_args()
         cmd = "python setup.py %s" % " ".join(sys.argv[1:])
         
@@ -745,13 +745,13 @@ if __name__ == "__main__":
         cmsVersion = cms.__version__.split('.')
 
         import django
-       
         django.setup()
         
         from django.conf import settings
        
         baseDir = settings.BASE_DIR
        
+        # check the project is cms installed.
         apps = [
             'cms',
             'menus',
@@ -887,6 +887,13 @@ if __name__ == "__main__":
             "If you encounter \"No such file or directory: "
             "/env/python3/lib/pythonx.x/site-packages/Django-x.x.x.dist-info/METADATA\" "
             "Please execute setup.py again.", "red"))
+        logger.error(colored(
+            "If you encounter error in \"django.setup()\", "
+            "Please use current virtual env(django==%s, cms==%s) to check the project can be run. "
+            "This error may come from a wrong version of django." % (djangoVersion, ".".join(cmsVersion)), "red"))
+        logger.error(colored(
+            "If you encounter \"Loaddata Error\", "
+            "Please check your database must be empty before load data.", "red"))
         print("")
         logger.warning(colored(
             "Get more instructions for using setup.py from the URL below:", 
